@@ -13,3 +13,11 @@ class ClusterConfig:
 
         self.cluster_name = cluster_name
         self.is_cluster = is_cluster
+
+
+class PlatoConfig(object):
+    def __init__(self):
+        self.plato_install_path = os.getenv("PLATO_PATH", "")
+
+
+plato_config = PlatoConfig()
