@@ -7,12 +7,10 @@ from utils.sql_merge_operation import SqlMergeHandler
 from utils.sql_replace_operation import SqlReplaceHandler
 from daos.common import deal_query_result, deal_query_result_sample, deal_query_result_sample_plus,\
     deal_query_result_with_paging
-
 logger = get_logger()
 cluster_config = ClusterConfig()
 sql_replace_handler = SqlReplaceHandler(cluster_config.is_cluster)
 
-
 class CHGraph(object):
 
     def __init__(self, client):
@@ -36,6 +34,9 @@ class CHGraph(object):
             return msg
 
         try:
+            """
+            创建子图的点边表
+            """
             for keyword in ["edges", "vertexes"]:
                 for _type, info in self.graph_cfg.get(keyword, {}).items():
                     self.create_subgraph_table(keyword, subgraph_name, info, cluster_config.is_cluster,
@@ -43,6 +44,17 @@ class CHGraph(object):
         except Exception as e:
             logger.error("create subgraph error. errMsg:{}".format(str(e)))
             return "subgraph is already exist or something wrong"
+        try:
+            """
+            创建子图的计算属性表
+            """
+            _type, info = self.graph_cfg.get("vertexes", {}).items()[0]
+            self.create_subgraph_ext_table("vertexes", subgraph_name, info, cluster_config.is_cluster,
+                                           cluster_config.cluster_name)
+        except Exception as e:
+            logger.error("create ext subgraph error. errMsg:{}".format(str(e)))
+            return "create ext table filed !!"
+
 
     def use_graph(self, graph_name, db):
         """
@@ -1300,9 +1312,48 @@ class CHGraph(object):
             logger.info("distributed table sql: {}".format(sql))
             self.client.execute(sql)
 
+    def single_create_table_sql(self, table_name):
+        """
+        拼接single SQL
+        """
+        # 字段
+        columns_str = "(\n    `id` String,\n   " \
+                      " `task_id` String,\n    " \
+                      " `id_type` String,\n    " \
+                      "`graph_algorithm_type` String,\n   " \
+                      " `val` String,\n    " \
+                      "`create_time` DateTime64(3) DEFAULT now() CODEC(DoubleDelta, LZ4)\n)\n"
+        engine_str = "ENGINE = MergeTree"
+        order_by_str = "order by id"
+        sql = "create table if not exists " + table_name + columns_str + \
+              engine_str + order_by_str + " SETTINGS index_granularity = 8192"
+        return sql
+    def create_subgraph_ext_table(self, graph_type, subgraph_name, edge_or_vertex_info, is_cluster, cluster_name):
+        """
+        创建子图额外属性的表
+        """
+        table_name = "calculation_attribute"
+        edge_or_vertex_info["table"] = table_name
+        if not is_cluster:
+            new_table_name = self.__gen_table_name(subgraph_name, table_name)
+            sql = self.single_create_table_sql(new_table_name)
+            self.client.execute(sql)
+        else:
+            table_schema_str = "(\n    id String,\n   " \
+                      " id_type String,\n    " \
+                      " task_id String,\n    " \
+                      " graph_algorithm_type String,\n   " \
+                      " val String,\n    " \
+                      " create_time DateTime64(3) DEFAULT now() CODEC(DoubleDelta, LZ4)\n)\n"
+            handler = SqlMergeHandler(graph_type, subgraph_name, edge_or_vertex_info, cluster_name)
+            # 创建本地表
+            sql = handler.gen_create_new_table_sql(table_schema_str)
+            logger.info("local table sql: {}".format(sql))
+            self.client.execute(sql)
 
-
-
-
+            # 创建分区表
+            sql = handler.gen_create_new_table_sql(table_schema_str, True)
+            logger.info("distributed table sql: {}".format(sql))
+            self.client.execute(sql)
 
 
