@@ -21,6 +21,7 @@ def disconnect_client(client):
 
 
 class ModelService(object):
+    calculations = ["pagerank", "closeness", "betweenness"]
     # 切换图空间
     def use_graph(self, graph_name, db):
         res = db.use_tables(graph_name)
@@ -33,6 +34,17 @@ class ModelService(object):
             self.graph_cfg = res
             logger.info("use graph [" + graph_name + "] done")
 
+    def get_graph_task(self, graph_name, db):
+        res = db.get_task(graph_name)
+        print(res)
+        if res is None:
+            logger.warning("get_graph_task ,graph name [" + graph_name + "] does not exist")
+            return
+        else:
+            logger.info("get_graph_task  [" + graph_name + "] done")
+            return ",".join(res)
+
+
     def search_subgraph_by_condition(self, data, config_param):
         """
         根据条件过滤查询子图
@@ -367,6 +379,72 @@ class ModelService(object):
         return result_dict
 
 
+    def calculation_attribute_select_function(self, data, config_param, label_statistic=None, graph=None):
+        """
+        计算属性查询
+        """
+        data = dispose_parse_params(data)
+        graph_name = data.get("subGraph")
+        compute = data.get("compute")
+        task_id = data.get("taskId")
+        if not graph_name:
+            return
+        # 获取客户端
+        db = config_param["db"]
+        clickhouse_connect = config_param["clickhouse_connect"]
+        graph_client = get_client(clickhouse_connect)
+        if not graph:
+            graph = CHGraph(graph_client)
+
+        # 更换子图
+        # self.use_graph(graph_name, db)
+        computes, task_str = self.execute_params_2_calculation(compute, task_id)
+        if task_str is None:
+            task_str = self.get_graph_task(graph_name, db)
+        if task_str is None:
+            return None
+        column_str = ""
+        for com in computes:
+            column_str = column_str + " ,sumIf(val,graph_algorithm_type = '"+com+"') as  " + com
+
+        execute_sql = "select id ,id_type " + column_str + "  from " + graph_name +\
+                      ".calculation_attribute where task_id in " \
+                      " ( "+task_str + ") group by id,id_type"
+        result_dict = execute_graph_sql(graph, execute_sql)
+
+        return result_dict
+
+
+    def calculation_attribute_submit_function(self, data, config_param, label_statistic=None, graph=None):
+        """
+        计算任务提交
+        """
+        data = dispose_parse_params(data)
+        graph_name = data.get("subGraph")
+        compute = data.get("compute")
+        task_id = data.get("taskId")
+        if not graph_name or not task_id or not compute:
+            return None
+        # 获取客户端
+        db = config_param["db"]
+        clickhouse_connect = config_param["clickhouse_connect"]
+        graph_client = get_client(clickhouse_connect)
+        if not graph:
+            graph = CHGraph(graph_client)
+        #对接计算任务接口调用
+
+        return "success"
+
+    def execute_params_2_calculation(self, compute, task_id):
+        """
+        处理计算参数
+        """
+        if compute and task_id:
+            return [compute], task_id
+        else:
+            return self.calculations
+
+
 def join_sql(operations, group_field, order_operation,
             type_vertex, schema, field_list, subgraph_type):
     """
